Method: Azuki::Command::Db#push

Defined in:
lib/azuki/command/db.rb

#pushObject

db:push [DATABASE_URL]

push local data up to your app

DATABASE_URL should reference your local database. if not specified, it will be guessed from config/database.yml

-c, –chunksize SIZE # specify the number of rows to send in each batch -d, –debug # enable debugging output -e, –exclude TABLES # exclude the specified tables from the push -f, –filter REGEX # only push certain tables -r, –resume FILE # resume transfer described by a .dat file -t, –tables TABLES # only push the specified tables



23
24
25
26
27
28
29
30
31
32
# File 'lib/azuki/command/db.rb', line 23

def push
  load_taps
  opts = parse_taps_opts

  display("Warning: Data in the app '#{app}' will be overwritten and will not be recoverable.")

  if confirm_command
    taps_client(:push, opts)
  end
end